Index: trunk/src/org/openstreetmap/josm/actions/AutoScaleAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/AutoScaleAction.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/actions/AutoScaleAction.java	(revision 17786)
@@ -97,5 +97,5 @@
          * @param englishLabel English label
          * @return {@code AutoScaleMode} for given English label
-         * @throws IllegalArgumentException if Engligh label is unknown
+         * @throws IllegalArgumentException if English label is unknown
          */
         public static AutoScaleMode of(String englishLabel) {
@@ -116,5 +116,5 @@
     /** Time of last zoom to bounds action */
     protected long lastZoomTime = -1;
-    /** Last zommed bounds */
+    /** Last zoomed bounds */
     protected int lastZoomArea = -1;
 
Index: trunk/src/org/openstreetmap/josm/data/osm/search/SearchCompiler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/search/SearchCompiler.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/data/osm/search/SearchCompiler.java	(revision 17786)
@@ -309,5 +309,5 @@
                 throw new SearchParseError(tr(rxErrorMsg, e.getPattern(), e.getIndex(), e.getMessage()), e);
             } catch (IllegalArgumentException | StringIndexOutOfBoundsException e) {
-                // StringIndexOutOfBoundsException catched because of https://bugs.openjdk.java.net/browse/JI-9044959
+                // StringIndexOutOfBoundsException caught because of https://bugs.openjdk.java.net/browse/JI-9044959
                 // See #13870: To remove after we switch to a version of Java which resolves this bug
                 throw new SearchParseError(tr(rxErrorMsgNoPos, regex, e.getMessage()), e);
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/OverlappingWays.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/OverlappingWays.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/OverlappingWays.java	(revision 17786)
@@ -48,5 +48,5 @@
     private MultiMap<Pair<Node, Node>, WaySegment> nodePairs;
 
-    private boolean onlyKnwonLinear;
+    private boolean onlyKnownLinear;
     private boolean includeOther;
     private boolean ignoreLayer;
@@ -84,5 +84,5 @@
         nodePairs = new MultiMap<>(1000);
         includeOther = isBeforeUpload ? ValidatorPrefHelper.PREF_OTHER_UPLOAD.get() : ValidatorPrefHelper.PREF_OTHER.get();
-        onlyKnwonLinear = Config.getPref().getBoolean("overlapping-ways.only-known-linear", true);
+        onlyKnownLinear = Config.getPref().getBoolean("overlapping-ways.only-known-linear", true);
         ignoreLayer = Config.getPref().getBoolean("overlapping-ways.ignore-layer", false);
     }
@@ -193,5 +193,5 @@
                 type = OVERLAPPING_WATERWAY_LINEAR_WAY;
                 severity = Severity.WARNING;
-            } else if (!includeOther || onlyKnwonLinear) {
+            } else if (!includeOther || onlyKnownLinear) {
                 return;
             } else if (countHighway > 0) {
@@ -270,5 +270,5 @@
             return;
 
-        if (onlyKnwonLinear && (w.concernsArea() || w.getInterestingTags().isEmpty()))
+        if (onlyKnownLinear && (w.concernsArea() || w.getInterestingTags().isEmpty()))
             return;
 
Index: trunk/src/org/openstreetmap/josm/gui/MainApplication.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 17786)
@@ -1258,7 +1258,7 @@
                                 Utils.updateSystemProperty("java.net.preferIPv6Addresses", "true");
                                 if (!wasv6) {
-                                    Logging.info(tr("Detected useable IPv6 network, preferring IPv6 over IPv4 after next restart."));
+                                    Logging.info(tr("Detected usable IPv6 network, preferring IPv6 over IPv4 after next restart."));
                                 } else {
-                                    Logging.info(tr("Detected useable IPv6 network, preferring IPv6 over IPv4."));
+                                    Logging.info(tr("Detected usable IPv6 network, preferring IPv6 over IPv4."));
                                 }
                             }
@@ -1272,5 +1272,5 @@
                 }
                 if (wasv6 && !hasv6) {
-                    Logging.info(tr("Detected no useable IPv6 network, preferring IPv4 over IPv6 after next restart."));
+                    Logging.info(tr("Detected no usable IPv6 network, preferring IPv4 over IPv6 after next restart."));
                     Config.getPref().putBoolean("validated.ipv6", hasv6); // be sure it is stored before the restart!
                     RestartAction.restartJOSM();
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java	(revision 17786)
@@ -7,5 +7,4 @@
 import java.awt.geom.Rectangle2D;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.Iterator;
@@ -89,6 +88,6 @@
                 middleOffset + (doRotateText ? 1 : -1) * nb.getWidth() / 2, doRotateText);
 
-        // Order the glyphs along the line to ensure that they are drawn corretly.
-        Collections.sort(offsetGlyphs, Comparator.comparing(OffsetGlyph::getOffset));
+        // Order the glyphs along the line to ensure that they are drawn correctly.
+        offsetGlyphs.sort(Comparator.comparing(OffsetGlyph::getOffset));
 
         // Now translate all glyphs. This will modify the glyphs stored in gvs.
Index: trunk/src/org/openstreetmap/josm/io/rtklib/RtkLibPosReader.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/rtklib/RtkLibPosReader.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/io/rtklib/RtkLibPosReader.java	(revision 17786)
@@ -125,6 +125,6 @@
 
     /**
-     * Returns the number of coordinates that have been successfuly read.
-     * @return the number of coordinates that have been successfuly read
+     * Returns the number of coordinates that have been successfully read.
+     * @return the number of coordinates that have been successfully read
      */
     public int getNumberOfCoordinates() {

Index: trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java	(revision 17785)
+++ trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java	(revision 17786)
@@ -254,8 +254,7 @@
     /**
      * Get projections this imagery layer supports natively.
-     *
-     * For example projection of tiles that are downloaded from a server. Layer
-     * may support even more projections (by reprojecting the tiles), but with a
-     * certain loss in image quality and performance.
+     * <p/>
+     * For example projection of tiles that are downloaded from a server. Layer may support even more
+     * projections (by reprojecting the tiles), but with a certain loss in image quality and performance.
      * @return projections this imagery layer supports natively; null if layer is projection agnostic.
      */
@@ -644,5 +643,5 @@
         int maxYtiles = (int) Math.ceil((double) height / tileSize + 1);
         int maxXtiles = (int) Math.ceil((double) width / tileSize + 1);
-        int visibileTiles = maxXtiles * maxYtiles;
+        int visibleTiles = maxXtiles * maxYtiles;
         /**
          * Take into account ZOOM_OFFSET to calculate real number of tiles and multiply by 7, to cover all tiles, that might be
@@ -659,12 +658,12 @@
          *
          * Add +2 to maxYtiles / maxXtiles to add space in cache for extra tiles in current zoom level that are
          * download by overloadTiles(). This is not added in computation of visibileTiles as this unnecessarily grow the cache size
          * @see #overloadTiles()
          */
         int ret = (int) Math.ceil(
                 Math.pow(2d, ZOOM_OFFSET.get()) * // use offset to decide, how many tiles are visible
-                visibileTiles * 7 + // 7 to cover tiles from other zooms as described above
+                visibleTiles * 7 + // 7 to cover tiles from other zooms as described above
                 ((maxYtiles + 2) * (maxXtiles +2))); // to add as many tiles as they will be accessed on current zoom level
-        Logging.info("AbstractTileSourceLayer: estimated visibile tiles: {0}, estimated cache size: {1}", visibileTiles, ret);
+        Logging.info("AbstractTileSourceLayer: estimated visible tiles: {0}, estimated cache size: {1}", visibleTiles, ret);
         return ret;
     }
@@ -868,5 +867,5 @@
      * Zoom out from map.
      *
-     * @return    true, if zoom increasing was successful, false othervise
+     * @return    true, if zoom increasing was successful, false otherwise
      */
     public boolean decreaseZoomLevel() {
@@ -659,12 +658,12 @@
          *
          * Add +2 to maxYtiles / maxXtiles to add space in cache for extra tiles in current zoom level that are
-         * download by overloadTiles(). This is not added in computation of visibileTiles as this unnecessarily grow the cache size
+         * download by overloadTiles(). This is not added in computation of visibleTiles as this unnecessarily grow the cache size
          * @see #overloadTiles()
          */